package edu.travel.web;

import com.baomidou.mybatisplus.extension.service.IService;
import edu.travel.interfaces.InsertGroups;
import edu.travel.interfaces.UpdateGroups;
import edu.travel.resp.BaseResponse;
import edu.travel.resp.PageResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.http.HttpStatus;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.Errors;
import org.springframework.validation.ObjectError;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

public class BaseController<T> {
    @Autowired
    @Lazy
    private IService<T> service;
    @GetMapping("/getById")
    public BaseResponse getById(String id) {
        T byId = service.getById(id);
        return PageResponse.out(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), byId);
    }
    @PostMapping("/updateById")
    @Transactional
    public BaseResponse<T> updateTargetById(@RequestBody T entity) {
        boolean update = service.updateById(entity);
        if (update) {
            return PageResponse.out(200,"success",entity);
        }
        return PageResponse.out(500,"error",entity);
    }
    @PostMapping("/save")
    @Transactional
    public BaseResponse<T> saveTarget(@RequestBody T entity) {
        boolean save = service.save(entity);
        if (save) {
            return PageResponse.out(200,"success",entity);
        }
        return PageResponse.out(500,"error",entity);
    }
    @PostMapping("/deleteById")
    @Transactional
    public BaseResponse<T> deleteTargetById(@RequestBody List<String> ids) {
        if (ids == null || ids.isEmpty()) {
            return PageResponse.out(404,"error,not found delete data",null);
        }
        boolean byIds = service.removeByIds(ids);
        if (byIds) {
            return PageResponse.out(200,"success",null);
        }
        return PageResponse.out(500,"error, delete data error",null);
    }
    @GetMapping("/list")
    public BaseResponse<List<T>> listAll() {
        List<T> list = service.list();
        if (list.isEmpty()) {
            return PageResponse.out(200,"success",null);
        }
        return PageResponse.out(404,"error,not found delete data",list);
    }



}
